==> SIMATH-3.10.1.tar.gz: SIMATH-3.10.1/sim/_calc.h <==
#include <_pol4.h>

#include <signal.h>

#undef printf
#define printf yprintf

#undef putc
# define putc(c,pf) xputc(c)

#undef puti
# define puti yputi

#undef putr
# define putr yputr

#undef putrd
# define putrd yputrd

#undef puta
# define puta yputa

#undef putl
# define putl yputl

#undef putpi
# define putpi yputpi

#undef putpr
# define putpr yputpr

#undef puts
# define puts yputs

#undef puto
# define puto(a) (isatom(a)?yputa(a):yputl(a))

#undef putbits
# define putbits yputbits

#undef putfl
# define putfl yputfl

#undef putflfx
# define putflfx yputflfx

#undef putnfel
# define putnfel yputnfel
	
#undef putqnfid
# define putqnfid yputqnfid

#undef putpnf 
# define putpnf yputpnf

#undef putpm 
# define putpm yputpm

#undef putgfsel
# define putgfsel yputgfsel

# undef putgf2el
# define putgf2el yputgf2el

# undef putpgfs
# define putpgfs yputpgfs

# undef putpgf2
# define putpgf2 yputpgf2

#define strcat2( s,a,b ) ( *s='\0', strcat(strcat(s,a),b) )
#define  strcat3( s,a,b,c )  strcat( strcat2( s,a,b ), c )
#define  strcat4( s,a,b,c,d )  strcat( strcat( strcat2( s,a,b ), c ), d )
#define itoc(N) (N ? ( issingle(N) ? list2(list2(0,N),0) : list2(flcons(N,0,llength(N)),0) ) : 0)
#define fltoc(N) (N ? list2(N,0) : 0)

extern single ITERMAX;

# define gf2elred(Gn,a,Gm)  udpm2togf2el(Gm,gf2eltoudpm2(Gn,a)) 
# define gfselred(p,a,Gm) pmsrem(1,p,pitopms(1,a,p),Gm)

#ifdef apollo
#define ___APO_RAM    /** fuer APOLLO **/
#endif

# ifdef ___LARGE_SYSTEM
#define MAXLV 50000
#define MAXL 100000
# else
#define MAXLV 5000
#define MAXL 10000
# endif 

#define  NUM_FUNC 196
# ifdef ___APO_RAM
# define VARLISTLENGTH 296
# else
#define  VARLISTLENGTH 496
# endif
extern struct var{
	char *varname;
	single typ;
	obj varwert;
} varlist[VARLISTLENGTH], localvar[VARLISTLENGTH];

# define USER_FUNC 50

# ifdef ___SMALL_SYSTEM
# define AVLENGTH 200
# else
# define AVLENGTH 500
# endif

extern char *funstr[USER_FUNC];

extern obj AV[AVLENGTH];
extern char AVNAME[3];

char *malloc(), *ctime();
long time();
FILE *fopen();

extern FILE *datei, *fpt[10];
extern char *comm,*dhelp, *datn, *fname[10];
extern single ps, hps, cellc, cellabs, tdiff, tabs, statsch, owsch, owalt, fz; 
extern single DIGITS, OUTPUTDIG, MX, MXNUM, MXUSER, DEPTH, LINELN, outct;
extern floating HEIGHTBOUND;
extern single ecqnfsch, ecsch, modsch, ssch, pzsch, nfsch, gfsch; 
extern single gfchar, nfon, avsch;
extern single fosch, schleife, breaksch;
extern single assch,prfehl;
extern list VNF, VGF;
extern single anzloc, funktion;

==> SIMATH-3.10.3.tar.gz: SIMATH-3.10.3/sim/_calc.h <==
#include <_pol4.h>

#include <signal.h>

#undef printf
#define printf yprintf

#undef putc
# define putc(c,pf) xputc(c)

#undef puti
# define puti yputi

#undef putr
# define putr yputr

#undef putrd
# define putrd yputrd

#undef puta
# define puta yputa

#undef putl
# define putl yputl

#undef putpi
# define putpi yputpi

#undef putpr
# define putpr yputpr

#undef puts
# define puts yputs

#undef puto
# define puto(a) (isatom(a)?yputa(a):yputl(a))

#undef putbits
# define putbits yputbits

#undef putfl
# define putfl yputfl

#undef putflfx
# define putflfx yputflfx

#undef putnfel
# define putnfel yputnfel
	
#undef putqnfid
# define putqnfid yputqnfid

#undef putpnf 
# define putpnf yputpnf

#undef putpm 
# define putpm yputpm

#undef putgfsel
# define putgfsel yputgfsel

# undef putgf2el
# define putgf2el yputgf2el

# undef putpgfs
# define putpgfs yputpgfs

# undef putpgf2
# define putpgf2 yputpgf2

#define strcat2( s,a,b ) ( *s='\0', strcat(strcat(s,a),b) )
#define  strcat3( s,a,b,c )  strcat( strcat2( s,a,b ), c )
#define  strcat4( s,a,b,c,d )  strcat( strcat( strcat2( s,a,b ), c ), d )
#define itoc(N) (N ? ( issingle(N) ? list2(list2(0,N),0) : list2(flcons(N,0,llength(N)),0) ) : 0)
#define fltoc(N) (N ? list2(N,0) : 0)

extern single ITERMAX;

# define gf2elred(a,Gm)  udpm2togf2el(Gm,gf2etudpm2(a)) 
# define gfselred(p,a,Gm) pmsrem(1,p,pitopms(1,a,p),Gm)

#ifdef apollo
#define ___APO_RAM    /** fuer APOLLO **/
#endif

# ifdef ___LARGE_SYSTEM
#define MAXLV 50000
#define MAXL 100000
# else
#define MAXLV 5000
#define MAXL 10000
# endif 

#define  NUM_FUNC 207
# ifdef ___APO_RAM
# define VARLISTLENGTH 307
# else
#define  VARLISTLENGTH 507
# endif
extern struct var{
	char *varname;
	single typ;
	obj varwert;
} varlist[VARLISTLENGTH], localvar[VARLISTLENGTH];

# define USER_FUNC 50

# ifdef ___SMALL_SYSTEM
# define AVLENGTH 200
# else
# define AVLENGTH 500
# endif

extern char *funstr[USER_FUNC];

extern obj AV[AVLENGTH];
extern char AVNAME[3];

char *malloc(), *ctime();
long time();
FILE *fopen();

extern FILE *datei, *fpt[10];
extern char *comm,*dhelp, *datn, *fname[10];
extern single ps, hps, cellc, cellabs, tdiff, tabs, statsch, owsch, owalt, fz; 
extern single DIGITS, OUTPUTDIG, MX, MXNUM, MXUSER, DEPTH, LINELN, outct;
extern floating HEIGHTBOUND;
extern single ecqnfsch, ecsch, modsch, ssch, pzsch, nfsch, gfsch; 
extern single gfchar, nfon, avsch;
extern single fosch, schleife, breaksch;
extern single assch,prfehl;
extern list VNF, VGF;
extern single anzloc, funktion;
